@@ -1,10 +1,9 @@
-from abc import ABC
 from uuid import UUID
 from sqlalchemy.dialects.mysql import BINARY
 from sqlalchemy.types import TypeDecorator
 
 
-class BinaryUUID(TypeDecorator, ABC):
+class BinaryUUID(TypeDecorator):
     """Optimize UUID keys. Store as 16 bit binary, retrieve as uuid.
     inspired by:
         https://mysqlserverteam.com/storing-uuid-values-in-mysql-tables/
