@@ -10,3 +10,7 @@ def convert_date_to_timestamp(date, format_datetime='%Y-%m-%d %H:%M:%S'):
         raise ValueError('Incorrect data type')
 
     return int(date.astimezone(pytz.UTC).timestamp())
+
+
+def get_timestamp_now():
+    return int(datetime.now().astimezone(pytz.utc).timestamp())
